"use strict";
/*
  Copyright (C) Microsoft Corporation.    All rights reserved.
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
  EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
 */
/// <reference path="../../typing/ControlFramework.d.ts"/>
/// <reference path="./private_typing/inputsOutputs.d.ts"/>
/// <reference path="./Platform.ts"/>
var ProductVisualize;
(function (ProductVisualize) {
    var ProductVisualizeControl = /** @class */ (function () {
        function ProductVisualizeControl() {
        }
        /**
         * Used to initialize the control instance. Controls can kick off remote server calls and other initialization actions here.
         * Data-set values are not initialized here, use updateView.
         * @param context The entire property bag available to control via Context Object; It contains values as set up by the customizer mapped to property names defined in the manifest, as well as utility functions.
         * @param notifyOutputChanged A callback method to alert the framework that the control has new outputs ready to be retrieved asynchronously.
         * @param state A piece of data that persists in one session for a single user. Can be set at any point in a controls life cycle by calling 'setControlState' in the Mode interface.
         * @param container If a control is marked control-type='starndard', it will receive an empty div element within which it can render its content.
         */
        ProductVisualizeControl.prototype.init = function (context, notifyOutputChanged, state, container) {
            this.context = context;
            this.container = container;
            // Show the control
            this.createMainView();
        };
        /**
         * Called when any value in the property bag has changed. This includes field values, data-sets, global values such as container height and width, offline status, control metadata values such as label, visible, etc.
         * @param context The entire property bag available to control via Context Object; It contains values as set up by the customizer mapped to names defined in the manifest, as well as utility functions
         */
        ProductVisualizeControl.prototype.updateView = function (context) {
        };
        /**
         * It is called by the framework prior to a control receiving new data.
         * @returns an object based on nomenclature defined in manifest, expecting object[s] for property marked as “bound” or “output”
         */
        ProductVisualizeControl.prototype.getOutputs = function () {
            return {};
        };
        /**
            * Called when the control is to be removed from the DOM tree. Controls should use this call for cleanup.
         * i.e. cancelling any pending remote calls, removing listeners, etc.
         */
        ProductVisualizeControl.prototype.destroy = function () {
        };
        /**
         * Create the HTML for the primary view
         */
        ProductVisualizeControl.prototype.createMainView = function () {
            var _this = this;
            var controlDiv = document.createElement("div");
            controlDiv.classList.add("control", "controlgrid", "controlfont");
            var title = document.createElement("h1");
            title.classList.add("title");
            title.innerHTML = this.context.resources.getString("Title_Text_1") + " <br class=\"d365BR\"/>" + this.context.resources.getString("Title_Text_2") + " <br class=\"pvBR\"/>" + this.context.resources.getString("Title_Text_3");
            controlDiv.appendChild(title);
            var textDiv = document.createElement("div");
            textDiv.classList.add("content");
            controlDiv.appendChild(textDiv);
            var subtitle = document.createElement("p");
            subtitle.classList.add("subtitle");
            subtitle.innerText = this.context.resources.getString("SubTitle_Text");
            textDiv.appendChild(subtitle);
            var gettingStarted = document.createElement("p");
            gettingStarted.classList.add("gettingstarted");
            gettingStarted.innerText = this.context.resources.getString("GettingStarted_Text");
            textDiv.appendChild(gettingStarted);
            var buttonDiv = document.createElement("div");
            buttonDiv.classList.add("buttonDiv");
            controlDiv.appendChild(buttonDiv);
            var isSupportedPlatform = ProductVisualize.Platform.isSupportedPlatform() && !ProductVisualize.Platform.isMobileApp();
            var buttonFunction = (isSupportedPlatform) ? this.launchSalesAssist.bind(this) : this.launchWebsite.bind(this);
            var button = document.createElement("button");
            button.classList.add("button", "buttonPrimary");
            button.addEventListener("click", function () { return buttonFunction(); });
            buttonDiv.appendChild(button);
            var buttonTextResource = (isSupportedPlatform) ? "Button_Text_Supported_Platform" : "Button_Text_Unsupported_Platform";
            var buttonTextShort = document.createElement("span");
            buttonTextShort.innerText = this.context.resources.getString(buttonTextResource + "_Short");
            buttonTextShort.classList.add("buttontextshort");
            button.appendChild(buttonTextShort);
            var buttonTextLong = document.createElement("span");
            buttonTextLong.innerText = this.context.resources.getString(buttonTextResource);
            buttonTextLong.classList.add("buttontextlong");
            button.appendChild(buttonTextLong);
            if (isSupportedPlatform) {
                var getAppLink = document.createElement("button");
                getAppLink.innerText = this.context.resources.getString("GetAppLink_Text");
                getAppLink.classList.add("button", "buttonSecondary");
                getAppLink.addEventListener("click", function () { return _this.launchAppStore.bind(_this)(); });
                buttonDiv.appendChild(getAppLink);
            }
            var image = document.createElement("img");
            image.classList.add("image");
            controlDiv.appendChild(image);
            this.loadImage("productVisualize.jpg", image);
            var footer = document.createElement("p");
            footer.classList.add("copyrightText");
            footer.innerHTML = "&copy; " + this.context.resources.getString("Copyright_Text");
            controlDiv.appendChild(footer);
            this.container.appendChild(controlDiv);
        };
        /**
         * Loads an image from the control's resources
         * @param src Source file name
         * @param image Image element to apply the image to
         */
        ProductVisualizeControl.prototype.loadImage = function (src, image) {
            this.context.resources.getResource(src, function (content) {
                image.src = "data:image/jpg;base64, " + content;
            }, function () { return console.log("Failed to load image"); });
        };
        /**
         * The mobile app adds '--d' to the org name in the client URL, remove it before sending it off to the app
         */
        ProductVisualizeControl.prototype.getClientUrl = function () {
            var clientUrl = this.context.page.getClientUrl();
            return clientUrl.replace(/(https:\/\/)(.+)(\.crm\.dynamics\.com)/, function (match, front, orgName, end) {
                return "" + front + orgName.replace("--d", "") + end;
            });
        };
        /**
         * Launch the platform App's store
         */
        ProductVisualizeControl.prototype.launchAppStore = function () {
            console.log("App Store");
            console.log("Context: " + (this.context != null));
            console.log("Navigation: " + (this.context.navigation != null));
            this.context.navigation.openUrl("https://itunes.apple.com/us/app/dynamics-365-product-visualize/id1437454781?mt=8");
        };
        /**
         * Launches Sales Assist
         */
        ProductVisualizeControl.prototype.launchSalesAssist = function () {
            // Get the opportunity ID and base URL of the Dynamics instance
            var entityId = this.context.page.entityId;
            var hostname = this.getClientUrl();
            // Launch Sales Assist
            var launchUrl = "mrwmonterrey://test"
                + "?launchSource=Dynamics"
                + "&projectSource=Dynamics"
                + ("&orgUrl=" + hostname)
                + ("&opportunityId=" + entityId);
            this.context.navigation.openUrl(launchUrl);
        };
        /**
         * Launch the Product Visualize Website
         */
        ProductVisualizeControl.prototype.launchWebsite = function () {
            this.context.navigation.openUrl("https://dynamics.microsoft.com/en-us/mixed-reality/product-visualize/");
        };
        return ProductVisualizeControl;
    }());
    ProductVisualize.ProductVisualizeControl = ProductVisualizeControl;
})(ProductVisualize || (ProductVisualize = {}));
